@@ -831,7 +831,7 @@ With a prefix argument, prompt for cvs FLAGS to use."
 
 (defun-cvs-mode (cvs-mode-revert-buffer . SIMPLE)
                 (&optional ignore-auto noconfirm)
-  "Rerun cvs-examine on the current directory with the defauls flags."
+  "Rerun cvs-examine on the current directory with the default flags."
   (interactive)
   (cvs-examine default-directory t))
 
@@ -1957,7 +1957,7 @@ this file, or a list of arguments to send to the program."
 	    (ignore-errors
 	      ;; Ideally, we'd like to prevent changing the (minor) modes.
 	      ;; But we do want to reset the mode for some cases, most notably
-	      ;; VC.  Maybe it'd better to reset VC explicitely ?
+	      ;; VC.  Maybe it'd better to reset VC explicitly ?
 	      (revert-buffer 'ignore-auto 'dont-ask)) ; 'preserve-modes
 	    ;; protect the buffer-read-only setting
 	    (if cvs-buf-was-ro (toggle-read-only 1))))))))
